@@ -5,12 +5,11 @@ from .groceries_real import GroceriesReal
 from .nyudepth import NyuDepth
 from .synthetic import SynDetection2D
 
-
 __all__ = [
     Cityscapes,
     CocoDetection,
     Dataset,
     GroceriesReal,
     NyuDepth,
-    SynDetection2D
+    SynDetection2D,
 ]
