@@ -1,7 +1,6 @@
 from .captures import Captures
-from .references import AnnotationDefinitions, MetricDefinitions, Egos, Sensors
 from .metrics import Metrics
-
+from .references import AnnotationDefinitions, Egos, MetricDefinitions, Sensors
 
 __all__ = [
     AnnotationDefinitions,
