@@ -3,9 +3,4 @@ from .deeplab import DeeplabV3
 from .densedepth import DenseDepth
 from .faster_rcnn import FasterRCNN
 
-__all__ = [
-    Estimator,
-    DeeplabV3,
-    DenseDepth,
-    FasterRCNN
-]
+__all__ = [Estimator, DeeplabV3, DenseDepth, FasterRCNN]
