@@ -3,11 +3,11 @@ import logging
 import math
 from typing import Dict, List, Tuple
 
-from codetiming import Timer
 import numpy as np
 import torch
 import torch.distributed as dist
 import torchvision
+from codetiming import Timer
 
 import datasetinsights.constants as const
 from datasetinsights.data.bbox import BBox2D
@@ -15,8 +15,8 @@ from datasetinsights.data.datasets import Dataset
 from datasetinsights.data.transforms import Compose
 from datasetinsights.evaluation_metrics.base import EvaluationMetric
 from datasetinsights.torch_distributed import get_world_size
-from .base import Estimator
 
+from .base import Estimator
 
 MAX_BOXES_PER_IMAGE = 100
 logger = logging.getLogger(__name__)
@@ -228,8 +228,7 @@ def train_one_epoch(
             optimizer.zero_grad()
     writer.add_scalar("training/loss", loss_metric.compute(), epoch)
     writer.add_scalar(
-        "training/running_loss", loss_metric.compute(),
-        loss_metric.num_examples
+        "training/running_loss", loss_metric.compute(), loss_metric.num_examples
     )
     writer.add_scalar("training/lr", optimizer.param_groups[0]["lr"], epoch)
     loss_metric.reset()
@@ -256,8 +255,14 @@ def list2canonical(box_list):
     Returns (BBox2d):
 
     """
-    return BBox2D(label=box_list[0], score=box_list[1], x=box_list[2],
-                  y=box_list[3], w=box_list[4], h=box_list[5])
+    return BBox2D(
+        label=box_list[0],
+        score=box_list[1],
+        x=box_list[2],
+        y=box_list[3],
+        w=box_list[4],
+        h=box_list[5],
+    )
 
 
 def list3d_2canonical(batch):
