@@ -6,6 +6,7 @@ The root mean square error can be described as:
     \sqrt{\frac{1}{n}\sum_{p}^{n}{(y_p-\hat{y_p})}^2}
 """
 from math import sqrt
+
 import numpy as np
 
 from .base import EvaluationMetric
@@ -34,8 +35,10 @@ class RootMeanSquareError(EvaluationMetric):
     def update(self, output):
         y_pred, y = output
         if y.shape != y_pred.shape:
-            raise ValueError(f'The shapes of real data {y.shape} and predicted data {y_pred.shape} \
-                               should be the same.')
+            raise ValueError(
+                f"The shapes of real data {y.shape} and predicted data {y_pred.shape} \
+                               should be the same."
+            )
 
         self.num_samples += y.shape[0]
         self.sum_of_root_mean_square_error += (
